@@ -1,10 +1,10 @@
 ## no critic (RequireUseStrict)
 package Tapper::Reports::DPath;
-# git description: v4.1.1-13-g63aed9c
+# git description: v5.0.0-1-ge220fb8
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Extended DPath functionality for Tapper reports
-$Tapper::Reports::DPath::VERSION = '5.0.0';
+$Tapper::Reports::DPath::VERSION = '5.0.1';
 use 5.010;
         use Moose;
 
@@ -188,8 +188,6 @@ use 5.010;
                                                skipped
                                                todo
                                                todo_passed
-                                               wait
-                                               exit
                                                success_ratio
                                                starttime_test_program
                                                endtime_test_program
@@ -320,7 +318,7 @@ use 5.010;
                                 $rgt_stats->update_failed_passed;
                                 $rgt_stats->insert;
                         }
-                        my @stat_fields = (qw/failed passed total parse_errors skipped todo todo_passed wait success_ratio/);
+                        my @stat_fields = (qw/failed passed total parse_errors skipped todo todo_passed success_ratio/);
                         no strict 'refs'; ## no critic (ProhibitNoStrict)
                         $reportgroupstats = {
                                              map { ($_ => $rgt_stats->$_ ) } @stat_fields
